========
Créditos
========

Autor
-------------

PyCEPCorreios foi desenvolvido originalmente por:

* Michell Stuttgart <michellstut@gmail.com>

Contribuidores
--------------

Agradecimentos aos seguintes contribuidores pelo esforço de fazer a PyCEPCorreios
melhor:

* `Lista de contribuidores <https://github.com/mstuttgart/pycep-correios/graphs/contributors>`_
